# Changelog

## [0.3.0](https://github.com/SarthakJariwala/sqlsaber/compare/sqlsaber-viz-v0.2.0...sqlsaber-viz-v0.3.0) (2026-02-09)


### Features

* Implement a generic model/API-key override approach for tools ([#122](https://github.com/SarthakJariwala/sqlsaber/issues/122)) ([8dcf785](https://github.com/SarthakJariwala/sqlsaber/commit/8dcf7856bffca5f7fe1b85a78f1636988f568598))
* Implement a generic model/API-key override approach for tools ([#122](https://github.com/SarthakJariwala/sqlsaber/issues/122)) ([b880d5e](https://github.com/SarthakJariwala/sqlsaber/commit/b880d5e3674d0d3bb08392d29113c00cb1aa6a0f))

## [0.2.0](https://github.com/SarthakJariwala/sqlsaber/compare/sqlsaber-viz-v0.1.1...sqlsaber-viz-v0.2.0) (2026-02-06)


### Features

* allow overriding subagent model configuration via cli ([#118](https://github.com/SarthakJariwala/sqlsaber/issues/118)) ([ac31f8d](https://github.com/SarthakJariwala/sqlsaber/commit/ac31f8d71d328ab956f1f399a71e38ff5f769f7e))
* visualization model override support via api and prompt improvements ([35a506b](https://github.com/SarthakJariwala/sqlsaber/commit/35a506b23337dd64f8f20606e7e547755eae6f21))

## [0.1.1](https://github.com/SarthakJariwala/sqlsaber/compare/sqlsaber-viz-v0.1.0...sqlsaber-viz-v0.1.1) (2026-02-05)


### Features

* first plugins release ([bd1a5b5](https://github.com/SarthakJariwala/sqlsaber/commit/bd1a5b5079d6eaff2a52bdf4b8812d54ea8c2783))
